from bencherscaffold.protoclasses import bencher_pb2 as _bencher_pb2
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor
